"""Autogenerated API"""
from argus_api.session import get_session
from typing import TYPE_CHECKING, Optional
if TYPE_CHECKING:
    from argus_api.session import ArgusAPISession


def get_functions(
    onlyRoles: bool = None,
    keywords: str = None,
    limit: int = 25,
    requirePermission: bool = True,
    maxSecurityLevel: str = "current",
    offset: int = None,
    json: bool = True,
    verify: Optional[bool] = None,
    proxies: Optional[dict] = None,
    apiKey: Optional[str] = None,
    authentication: Optional[dict] = None,
    server_url: Optional[str] = None,
    body: Optional[dict] = None,
    api_session: Optional["ArgusAPISession"] = None,
) -> dict:
    """List the current user's permission functions regardless of customer (PUBLIC)
    
    :param bool onlyRoles: Only return functions marked as roles
    :param list keywords: Filter functions by keywords on name and description
    :param int limit: Maximum number of returned functions
    :param bool requirePermission: Only return functions which current user has access to
    :param str maxSecurityLevel: Only return functions which are available with this security level
    :param int offset: Skip a number of functions
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :param api_session: session to use for this request. If not set, the global session will be used.
    :raises AuthenticationFailedException: on 401
    :raises ForbiddenPermissionException: on 403
    :raises InvalidRequestException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/currentuser/v1/functions".format(limit=limit,
        requirePermission=requirePermission,
        maxSecurityLevel=maxSecurityLevel,
        offset=offset,
        onlyRoles=onlyRoles,
        keywords=keywords)

    session = api_session or get_session()
    headers = {}

    body = body or {}

    query_parameters = {}
    # Only send limit if the argument was provided, don't send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send requirePermission if the argument was provided, don't send null values
    if requirePermission is not None:
        query_parameters.update({"requirePermission": requirePermission})
    
    # Only send maxSecurityLevel if the argument was provided, don't send null values
    if maxSecurityLevel is not None:
        query_parameters.update({"maxSecurityLevel": maxSecurityLevel})
    
    # Only send offset if the argument was provided, don't send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    # Only send onlyRoles if the argument was provided, don't send null values
    if onlyRoles is not None:
        query_parameters.update({"onlyRoles": onlyRoles})
    
    # Only send keywords if the argument was provided, don't send null values
    if keywords is not None:
        query_parameters.update({"keywords": keywords})
    

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response
